@@ -249,6 +249,17 @@ class DSRequest(RPCRequest):
             ids = [(0, "none")]
         return ids
 
+    def get_olds_tuple_ids(self):
+        multi, data_array = self.get_data_array()
+        if data_array:
+            if multi:
+                ids = [(record.get('oldValues').get('id'), record.get('visibleMode', 'none')) for record in data_array]
+            else:
+                ids = [(record.get('oldValues').get('id'), self.visibleMode) if record.get('data') else (record.get('id'), self.visibleMode) for record in data_array]
+        else:
+            ids = [(0, "none")]
+        return ids
+
     def get_old_ids(self):
         multi, data_array = self.get_data_array()
         if data_array:
